summaryrefslogtreecommitdiffstats
path: root/Lib/smtplib.py
diff options
context:
space:
mode:
authorFred Drake <fdrake@acm.org>2001-10-13 18:35:32 (GMT)
committerFred Drake <fdrake@acm.org>2001-10-13 18:35:32 (GMT)
commit2f8f4d36785202d337cded7d40eaeff4ae7b3038 (patch)
tree0b1af9689d137b838a3f8b12db1c8832cd17f583 /Lib/smtplib.py
parentf902296a1889f9453ca0080525b8ffc1e21ed997 (diff)
downloadcpython-2f8f4d36785202d337cded7d40eaeff4ae7b3038.zip
cpython-2f8f4d36785202d337cded7d40eaeff4ae7b3038.tar.gz
cpython-2f8f4d36785202d337cded7d40eaeff4ae7b3038.tar.bz2
SMTPError should be SMTPException; reported by Neal Norwitz.
Diffstat (limited to 'Lib/smtplib.py')
-rwxr-xr-xLib/smtplib.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/Lib/smtplib.py b/Lib/smtplib.py
index 8e98608..d8b18e9 100755
--- a/Lib/smtplib.py
+++ b/Lib/smtplib.py
@@ -485,7 +485,7 @@ class SMTP:
the helo greeting.
SMTPAuthenticationError The server didn't accept the username/
password combination.
SMTPError No suitable authentication method was
found.
"""
@@ -537,7 +537,7 @@ class SMTP:
(code, resp) = self.docmd("AUTH",
AUTH_PLAIN + " " + encode_plain(user, password))
elif authmethod == None:
- raise SMTPError("No suitable authentication method found.")
+ raise SMTPException("No suitable authentication method found.")
if code not in [235, 503]:
# 235 == 'Authentication successful'
# 503 == 'Error: already authenticated'
@@ -485,7 +485,7 @@ class SMTP:
SMTPAuthenticationError The server didn't accept the username/
password combination.
- SMTPError No suitable authentication method was
+ SMTPException No suitable authentication method was
found.
"""